<?php
/**
 * @package WPNotifier
 * @version  v1.0
 *
 * 
 */
 
 class WPNotifier_Settings_Page
{

    /**
     * Start up
     */
    public function __construct()
    {
		
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
		add_menu_page(
			esc_html__( 'WP Notifier', 'wpnotifier' ),
			esc_html__( 'WP Notifier', 'wpnotifier' ),
			'manage_options',
			'wpnotifier-setting-admin',
			array( $this, 'create_admin_page' ),
			'dashicons-megaphone',
			6
		);
	      
        add_submenu_page(
            'wpnotifier-setting-admin',
            esc_html__( 'Add Notification', 'wpnotifier' ),
            esc_html__( 'Add Notification', 'wpnotifier' ),
            'manage_options',
            'edit.php?post_type=wpnotifier',
            NULL
        );



    }

	
	/**
	 * Donor Admin Page Callback
	 */
    
    function page_init() {
        //register our settings
        register_setting( 'wpnotifier-plugin-settings-group', 'wpnotifier_options' );
    }


    /**
     * Options page callback
     */
    public function create_admin_page()
    {
		
        ?>
        <div class="wpnotifier-admin-wrap">
			<?php 
			// add error/update messages
	        
			// check if the user have submitted the settings
			if ( isset( $_GET['settings-updated'] ) ) {
			// add settings saved message with the class of "updated"
			add_settings_error( 'wpnotifier_messages', 'wpnotifier_message', esc_html__( 'Settings Saved', 'wpnotifier' ), 'updated' );
			}
			
			// show error/update messages
			settings_errors( 'wpnotifier_messages' );

            $wpnotifier_options = get_option( 'wpnotifier_options' );
            $googlereview = get_option( 'wpnotifier_google_review' );

			?>
            <form class="admin-wpnotifier" method="post" action="options.php">
			    <?php settings_fields( 'wpnotifier-plugin-settings-group' ); ?>
                <?php do_settings_sections( 'wpnotifier-plugin-settings-group' ); ?>
                <!-- Google Review -->
                <?php
                $gookey    = !empty( $wpnotifier_options['gookey'] ) ? $wpnotifier_options['gookey'] : '';
                $gplaceid  = !empty( $wpnotifier_options['gplaceid'] ) ? $wpnotifier_options['gplaceid'] : '';
                $delaytime = !empty( $wpnotifier_options['delaytime'] ) ? $wpnotifier_options['delaytime'] : '5000';
                $hidedelaytime = !empty( $wpnotifier_options['hidedelaytime'] ) ? $wpnotifier_options['hidedelaytime'] : '3000';
                ?>
                <div class="wpnotifier-label wpnotifier-field-wrp">
                    <h5><?php esc_html_e( 'Set Google Api Key', 'wpnotifier' ); ?></h5>
                    <input type="text" class="mt-8 input-control" name="wpnotifier_options[gookey]" value="<?php echo esc_html( $gookey ); ?>"/>
                </div> 
                <div class="wpnotifier-label wpnotifier-field-wrp">
                    <h5><?php esc_html_e( 'Set Global Google Place ID', 'wpnotifier' ); ?></h5>
                    <input type="text" class="mt-8 input-control" name="wpnotifier_options[gplaceid]" value="<?php echo esc_html( $gplaceid ); ?>"/>
                </div> 
                <?php 
                if( !empty( $gookey ) && !empty( $gplaceid ) ):
                    
                ?>
                <div class="wpnotifier-label">
                    <?php if( empty( $googlereview )  ): ?>
                    <h5><?php esc_html_e( 'Click on this button to save google rating data in your database to show in notifaction.', 'wpnotifier' ); ?></h5>
                    <button class="add-google-data"><?php esc_html_e( 'Get Google Data', 'wpnotifier' ); ?></button>
                    <p class="response"></p>
                    <?php 
                    echo '<p class="wpnotifier-info wpnotifier-alert">'.esc_html__( 'Google review rating data not saved in your database yet.', 'wpnotifier' ).'</p>';
                    else:
                        echo '<p class="wpnotifier-info wpnotifier-success">'.esc_html__( 'Google review rating data saved in your database.', 'wpnotifier' ).'</p>';
                    endif;
                    ?>
                </div> 
                <?php 
                endif;
                ?>
                <div class="wpnotifier-label wpnotifier-field-wrp">
                    <h5><?php esc_html_e( 'Delay Time For Show', 'wpnotifier' ); ?></h5>
                    <input type="number" min="1000" class="mt-8 input-control" name="wpnotifier_options[delaytime]" value="<?php echo esc_html( $delaytime ); ?>"/>
                </div> 
                <div class="wpnotifier-label wpnotifier-field-wrp">
                    <h5><?php esc_html_e( 'Delay Time For Hide', 'wpnotifier' ); ?></h5>
                    <input type="number" min="500" class="mt-8 input-control" name="wpnotifier_options[hidedelaytime]" value="<?php echo esc_html( $hidedelaytime ); ?>"/>
                </div> 

            <?php
            // Save Button                    
            submit_button(); 
            ?>
            </form>
        </div>
        <?php
    }
	
	
}

if( is_admin() )
    $wpnotifier_settings_page = new WPNotifier_Settings_Page();

  