<?php 
 /**
  * 
  * @package    WPNotifier
  * @version    1.0
  * @author     WPBucket
  * @Websites: http://wpbucket.net
  *
  */
 

class WPNotifier_Google_API {

	private $APIUrl;
	private $apikey;
	public $placeId;


	function __construct( ) {

		$opt = get_option( 'wpnotifier_options' );


		$this->apikey 	= !empty( $opt['gookey'] ) ? $opt['gookey'] : '';
		$this->placeId  = !empty( $opt['gplaceid'] ) ? $opt['gplaceid'] : '';

		add_action( 'wp_ajax_update_google_review',array( $this, 'update_google_review' ) );
		add_action( 'wp_ajax_nopriv_update_google_review',array( $this, 'update_google_review' ) );
	}


	public function api_url() {
		
		$Url = 'https://maps.googleapis.com/maps/api/place/details/json';

		$peram =array(
			'placeid' 	=> $this->placeId,
			'fields'	=> 'name,rating,url,icon,user_ratings_total',
			'key' 		=> $this->apikey
		);

		$APIUrl = add_query_arg(
			$peram,
			$Url 
		);

		$this->APIUrl = esc_url_raw( $APIUrl );

	}

	public function get_place_data() {

		$data = wp_remote_get( $this->APIUrl  );

		if( ! is_wp_error( $data ) ) {
		
			$data = json_decode( $data['body'], true );

			if( ! empty( $data['error_message'] ) ) {
				return $data['error_message'];
			} else {
				return $data['result'];
			}


		} else {
			return '<h3 class="text-center">'.esc_html__( 'API Connection Failed', 'wpnotifier' ).'</h3>';
		}

	}


	public function update_google_review() {

		$message = [];

		$data = get_option( 'wpnotifier_google_review' );

		if( empty( $data ) ) {

			$this->api_url();

			$reviews = $this->get_new_reviews();

			
			if( is_array( $reviews ) ) {

				if( !empty( $reviews['place_info'] ) ) {

					$placeJsonData = wp_json_encode( $reviews['place_info'] );

					$result = update_option( 'wpnotifier_google_review', $placeJsonData );

					if( ! is_wp_error( $result ) ) {
						$message['place_message'] =  esc_html__( 'Place information update successfully.', 'wpnotifier' );
					} else {
						$message['place_message'] =  esc_html__( 'Something is wrong, Place information Failed to update. Please try again.', 'wpnotifier' );
					}
				} else {
					$message['place_message'] =  esc_html__( 'Get empty place information data.', 'wpnotifier' );
				}


			} else {
				$message['place_message'] = $reviews;
			}

		} else {
			$message['place_message'] = esc_html__( 'Place information already updated.', 'wpnotifier' );
		}


		echo wp_json_encode( $message );

		die();

	}

	public function get_new_reviews() {

		$getData = $this->get_place_data();

		if( is_array( $getData ) ) {

			$data = array(

				'place_info' => array(

					'icon' => $getData['icon'],
					'name' => $getData['name'],
					'url' => $getData['url'],
					'formatted_address' => $getData['formatted_address'],
					'formatted_phone_number' => $getData['formatted_phone_number'],
					'rating' => $getData['rating'],
					'user_ratings_total' => $getData['user_ratings_total']
				)
			);

			return $data;

		} else {
			return $getData;
		}

	}


}
