<?php
/**
 * Register meta box(es).
 */
function wpnotifier_register_meta_boxes() {
    add_meta_box( 'meta-box-id', esc_html__( 'Notifier Meta', 'wpnotifier' ), 'wpnotifier_display_callback', 'wpnotifier' );
}
add_action( 'add_meta_boxes', 'wpnotifier_register_meta_boxes' );
 
/**
 * Meta box display callback.
 *
 * @param WP_Post $post Current post object.
 */
function wpnotifier_display_callback( $post ) {

        // Add nonce for security and authentication.
        wp_nonce_field( 'wpnotifier_nonce_action', 'wpnotifier_nonce' );

        $switch       = get_post_meta( $post->ID, 'wpnotifier_switch', true );
        $notifiertype = get_post_meta( $post->ID, 'wpnotifier_notifiertype', true );
        $theme        = get_post_meta( $post->ID, 'wpnotifier_theme', true );
        $position     = get_post_meta( $post->ID, 'wpnotifier_position', true );
        $thumbnail    = get_post_meta( $post->ID, 'wpnotifier_thumbnail', true );
        
    ?>
    <div class="wpnotifier-meta-wrapper">

        <div class="wpnotifier-meta-field wpnotifier-switch">
            <h3><?php esc_html_e( 'Switch', 'wpnotifier' ); ?></h3>
            <div class="onoffswitch">
                <input type="checkbox" name="switch" class="onoffswitch-checkbox" id="wpnotifierswitch" <?php checked( $switch, 'on' ); ?> >
                <label class="onoffswitch-label" for="wpnotifierswitch">
                    <span class="onoffswitch-inner"></span>
                    <span class="onoffswitch-switch"></span>
                </label>
            </div>
        </div>

        <div class="wpnotifier-meta-field wpnotifier-type">
            <h3><?php esc_html_e( 'Notification Type', 'wpnotifier' ); ?></h3>
            <div class="wpnotifier-type-inner">
                <div class="single-type">
                   <label class="wpn-is-woocommerce" for="salesnoti"><?php esc_html_e( 'Sales Notification', 'wpnotifier' ); ?></label>
                   <input id="salesnoti" type="radio" value="sales_notification" <?php  checked( $notifiertype, 'sales_notification' ); ?> name="notifiertype" />
                </div>
                <div class="single-type">
                   <label class="wpn-is-woocommerce" for="cartitems"><?php esc_html_e( 'Cart Items', 'wpnotifier' ); ?></label>
                   <input id="cartitems" type="radio" value="cart_items" <?php  checked( $notifiertype, 'cart_items' ); ?> name="notifiertype" />
                </div>
                <div class="single-type">
                   <label class="wpn-is-woocommerce" for="wooreviews"><?php esc_html_e( 'Woo Last Reviews', 'wpnotifier' ); ?></label>
                   <input id="wooreviews" type="radio" value="woo_reviews_notification" <?php  checked( $notifiertype, 'woo_reviews_notification' ); ?> name="notifiertype" />
                </div>
                <div class="single-type">
                   <label class="google-review" for="googlereviews"><?php esc_html_e( 'Google Reviews', 'wpnotifier' ); ?></label>
                   <input id="googlereviews" type="radio" value="google_reviews_notification" <?php  checked( $notifiertype, 'google_reviews_notification' ); ?> name="notifiertype" />
                </div>
            </div>
            <div class="wpnadmin-alert-message" style="display: none;"></div>
        </div>
        <div class="wpnotifier-meta-field wpnotifier-theme">
            <h3><?php esc_html_e( 'Select Theme', 'wpnotifier' ); ?></h3>
            <div class="wpnotifier-theme-inner">
                <div class="single-theme"> 
                    <input id="theme1" class="theme-input" type="radio" value="theme1" name="theme" <?php  checked( $theme, 'theme1' ); ?>  />
                   <label for="theme1"><img src="<?php echo  WPNOTIFIER_DIR_URL.'assets/img/theme1.png'; ?>" /> </label>
                </div>
                <div class="single-theme">
                    <input id="theme2" type="radio" class="theme-input" value="theme2" name="theme" <?php  checked( $theme, 'theme2' ); ?> /> 
                    <label for="theme2"><img src="<?php echo  WPNOTIFIER_DIR_URL.'assets/img/theme2.png'; ?>" /></label>
                </div>
                <div class="single-theme">
                    <input id="theme3" type="radio" class="theme-input" value="theme3" name="theme" <?php  checked( $theme, 'theme3' ); ?> />
                    <label for="theme3"><img src="<?php echo  WPNOTIFIER_DIR_URL.'assets/img/theme3.png'; ?>" /></label>
                </div>
            </div>
        </div>
        <div class="wpnotifier-meta-field wpnotifier-custom-thumbnail">
            <h3><?php esc_html_e( 'Custom Thumbnail', 'wpnotifier' ); ?></h3>
            <input  class="custom-thumbnail wpn_background_image" type="text" name="thumbnail" value="<?php echo esc_url( $thumbnail ); ?>" />
            <input type="button" class="wpn_image_button button-primary" value="Insert Media" /> 
            <p><?php esc_html_e( 'Image size should be 100 x 100.', 'wpnotifier' ); ?></p>           
        </div>
        <div class="wpnotifier-meta-field wpnotifier-position">
            <h3><?php esc_html_e( 'Position', 'wpnotifier' ); ?></h3>
            <select name="position">
                <option <?php  selected( $position, 'left' ); ?> value="left"><?php esc_html_e( 'Bottom Left', 'wpnotifier' ); ?></option>
                <option <?php  selected( $position, 'right' ); ?> value="right"><?php esc_html_e( 'Bottom Right', 'wpnotifier' ); ?></option>
            </select>
        </div>

    </div>
    <?php 
}
 
/**
 * Save meta box content.
 *
 * @param int $post_id Post ID
 */
function wpnotifier_save_meta_box( $post_id ) {
    
  // Add nonce for security and authentication.
    $nonce_name   = isset( $_POST['wpnotifier_nonce'] ) ? $_POST['wpnotifier_nonce'] : '';
    $nonce_action = 'wpnotifier_nonce_action';

    // Check if nonce is valid.
    if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) ) {
        return;
    }

    // Check if user has permissions to save data.
    if ( ! current_user_can( 'edit_post', $post_id ) ) {
        return;
    }

    // Check if not an autosave.
    if ( wp_is_post_autosave( $post_id ) ) {
        return;
    }

    // Check if not a revision.
    if ( wp_is_post_revision( $post_id ) ) {
        return;
    }



    //
    if( isset( $_POST['switch'] ) ) {
        update_post_meta( $post_id, 'wpnotifier_switch', sanitize_text_field( $_POST['switch'] ) );
    }else {
        update_post_meta( $post_id, 'wpnotifier_switch', sanitize_text_field( 'off' ) );
    }
    //
    if( isset( $_POST['notifiertype'] ) ) {
        update_post_meta( $post_id, 'wpnotifier_notifiertype', sanitize_text_field( $_POST['notifiertype'] ) );
    }
    //
    if( isset( $_POST['theme'] ) ) {
        update_post_meta( $post_id, 'wpnotifier_theme', sanitize_text_field( $_POST['theme'] ) );
    }
    //
    if( isset( $_POST['position'] ) ) {
        update_post_meta( $post_id, 'wpnotifier_position', sanitize_text_field( $_POST['position'] ) );
    }
    //
    if( isset( $_POST['thumbnail'] ) ) {
        update_post_meta( $post_id, 'wpnotifier_thumbnail', sanitize_text_field( $_POST['thumbnail'] ) );
    }


}
add_action( 'save_post', 'wpnotifier_save_meta_box' );

