<?php
class Template {

	private $data = [];
	private $type = '';
	private $thumbnail = '';


	public function get_notifier_template( $data ) {

		$this->data = $data;
		$this->type = $this->data['notifiertype'];
		$this->thumbnail = !empty( $this->data['thumbnail'] ) ? $this->data['thumbnail'] : '';
		$this->template_init();

	}

	public function template_init() {
		$data = $this->data;
		?>
		<div class="wpnotifier-wrapper wpnotifier-<?php echo esc_attr( $data['theme'].' '.$data['position'] ); ?>">
			<div class="wpnotifier-inner">
				<?php 
				$this->getContent();
				?>
			</div>
		</div>
		<?php
	}

	public function order_content() {

	$order = $this->getNotificationData();


	if( !empty( $order ) ):

	?>
	<div class="sale-order image">
		<img src="<?php echo esc_url( $order['image'] ); ?>" />
	</div>
	<div class="sale-order-content content">
		<h5><?php esc_html_e( 'Last sale from', 'wpnotifier' ); echo ' '.esc_html( get_bloginfo('name') ); ?></h5>
		<p>
		<a href="<?php echo esc_url( $order['url'] ); ?>"><?php echo esc_html( $order['name'] ); ?></a>
		</p>
		<p class="time"> <?php echo esc_html( $order['order_date'] ); ?></p>
	</div>
	<?php
	else :
		echo '<p>'.esc_html__( 'There has no order at this moment', 'wpnotifier' ).'</p>';
	endif;
	}

	public function cart_content() {

		$count = $this->getNotificationData();

		$url = $this->thumbnail;
		?>
		<div class="image">
			<img src="<?php echo esc_url( $url ); ?>" />
		</div>
		<div class="content">
			<h5><?php esc_html_e( 'Items in your cart', 'wpnotifier' ); ?></h5>
			<p>
			<?php esc_html_e( 'Hey, You forgot', 'wpnotifier' ); ?> <strong class="cart-count"><?php echo  esc_html( $count ); ?></strong> <?php esc_html_e( 'items in your shopping cart.', 'wpnotifier' ); ?>
			</p>
			<p><?php esc_html_e( 'Click to view items.', 'wpnotifier' ); ?> <a href="<?php echo esc_url( wc_get_cart_url() ); ?>"><?php esc_html_e( 'View Cart', 'wpnotifier' ); ?></a> </p>
		</div>
		<?php
	}

	public function google_review_content() {

		$review = get_option('wpnotifier_google_review');

		$review = json_decode( $review, true );

		$url = esc_url( $review['icon'] );
		?>
		<div class="image">
			<img src="<?php echo esc_url( $url ); ?>" />
		</div>
		<div class="content">
			<h5><?php esc_html_e( 'Google Rating', 'wpnotifier' ); ?></h5>
			<p> <span class="rating--number"><?php echo esc_html( $review['rating'] ); ?></span> <span class="star--rating"><?php wpnotifier_star_review( esc_html( $review['rating'] ) ); ?></span> </p>
			<p class="time-style"><?php echo sprintf( esc_html__( 'Based on %s reviews', 'wpnotifier' ), $review['user_ratings_total'] ); ?></p>
			<p> <a href="<?php echo esc_url( $review['url'] ); ?>" class="reviews-link"><?php esc_html_e( 'View Reviews', 'wpnotifier' ); ?></a> </p>
		</div>
		<?php
	}

	public function last_woo_review_content() {

		$getReview = $this->getNotificationData();

		?>
		<div class="image">
			<img src="<?php echo esc_url( $getReview['img'] ); ?>" />
		</div>
		<div class="content woo-review">
			<h5><?php echo esc_html( $getReview['comment_author'] ); ?> <small><?php esc_html_e( 'Provided', 'wpnotifier' ); ?></small></h5>
			<p><span class="rating--number"><?php echo esc_html( $getReview['rating'] ); ?></span><span class="star--rating"><?php wpnotifier_star_review( $getReview['rating'] ); ?></span></p>
			<p>on <a href="<?php echo esc_url( $getReview['url'] ); ?>" target="_blank" ><?php echo esc_html( $getReview['title'] ); ?></a> </p>
			<p class="time-style"><?php echo esc_html( $getReview['time'] ); ?></p>
		</div>
		<?php

	}

	public function getContent() {

		switch( $this->type ) {

			case "cart_items" :
				$this->cart_content();
			break;
			case "sales_notification" :
				$this->order_content();
			break;
			case "google_reviews_notification" :
				$this->google_review_content();
			break;
			case "woo_reviews_notification" :
				$this->last_woo_review_content();
			break;

		}

	}


	public function getNotificationData() {

		$data = "";

		switch( $this->type ) {

			case "cart_items" :
				$cartCount = new Cart_Items();
    			$data = $cartCount->getCartItems();
			break;
			case "sales_notification":
				$order = new Last_Order();
	        	$data = $order->getLastOrder();
			break;
			case "woo_reviews_notification" :
				$reviews = new Last_Woo_Review();
				$data = $reviews->getLastWooReview();
			break;

		}

		return $data;

	}


}
